==================
Getting Started
==================

Installation
------------

You can install the package using `pip` or `pipenv`. It requires Python 3.6.0+ to run.

::

    pip install gibica

That's it ! Now you have everything to build and run your Gibica programs.

Hello, numbers !
----------------

For now Gibica doesn't understand strings so we cannot actually write the traditionnal "Hello, world!" program.
Nonetheless, we can write a first piece of code that display a number. Pretty much the same right ?!

::

    print(1);

Yes that's it. You can save that super fancy program in a file named `hello.gbc` and execute it with the following command :

::

    gibica hello.gbc

if **1** is printed on you screen, congratulation ! You have just written your first Gibica program !
